@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtXmlPatterns module of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,14 +23,14 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
-/* C++ code produced by gperf version 3.0.3 */
+/* C++ code produced by gperf version 3.0.4 */
 /* Command-line: gperf TokenLookup.gperf  */
 /* Computed positions: -k'1,3,$' */
 
@@ -61,7 +61,7 @@
 #error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
 #endif
 
-#line 107 "TokenLookup.gperf"
+#line 99 "TokenLookup.gperf"
 
 
 QT_BEGIN_NAMESPACE
@@ -69,7 +69,7 @@ QT_BEGIN_NAMESPACE
 namespace QPatternist
 {
 
-#line 101 "TokenLookup.gperf"
+#line 93 "TokenLookup.gperf"
 struct TokenMap
 {
     const char *name;
@@ -91,7 +91,7 @@ public:
 };
 
 inline unsigned int
-TokenLookup::hash (const char *str, unsigned int len)
+TokenLookup::hash (register const char *str, register unsigned int len)
 {
   static const unsigned char asso_values[] =
     {
@@ -122,7 +122,7 @@ TokenLookup::hash (const char *str, unsigned int len)
       230, 230, 230, 230, 230, 230, 230, 230, 230, 230,
       230, 230, 230, 230, 230, 230
     };
-  int hval = len;
+  register int hval = len;
 
   switch (hval)
     {
@@ -138,7 +138,7 @@ TokenLookup::hash (const char *str, unsigned int len)
 }
 
 const struct TokenMap *
-TokenLookup::value (const char *str, unsigned int len)
+TokenLookup::value (register const char *str, register unsigned int len)
 {
   enum
     {
@@ -151,276 +151,276 @@ TokenLookup::value (const char *str, unsigned int len)
 
   static const struct TokenMap wordlist[] =
     {
-      {"",ERROR}, {"",ERROR},
-#line 152 "TokenLookup.gperf"
-      {"eq",                       EQ},
-      {"",ERROR},
-#line 130 "TokenLookup.gperf"
-      {"by",                       BY},
-#line 153 "TokenLookup.gperf"
-      {"every",                    EVERY},
-      {"",ERROR},
-#line 123 "TokenLookup.gperf"
-      {"as",                       AS},
-      {"",ERROR},
-#line 148 "TokenLookup.gperf"
-      {"else",                     ELSE},
-#line 217 "TokenLookup.gperf"
-      {"where",                    WHERE},
-#line 204 "TokenLookup.gperf"
-      {"stable",                   STABLE},
-#line 126 "TokenLookup.gperf"
-      {"at",                       AT},
-      {"",ERROR},
-#line 131 "TokenLookup.gperf"
-      {"case",                     CASE},
-      {"",ERROR},
-#line 129 "TokenLookup.gperf"
-      {"boundary-space",           BOUNDARY_SPACE},
-#line 147 "TokenLookup.gperf"
-      {"element",                  ELEMENT},
-#line 132 "TokenLookup.gperf"
-      {"castable",                 CASTABLE},
-#line 127 "TokenLookup.gperf"
-      {"attribute",                ATTRIBUTE},
-      {"",ERROR},
-#line 154 "TokenLookup.gperf"
-      {"except",                   EXCEPT},
-#line 161 "TokenLookup.gperf"
-      {"ge",                       GE},
-      {"",ERROR},
-#line 133 "TokenLookup.gperf"
-      {"cast",                     CAST},
-#line 210 "TokenLookup.gperf"
-      {"treat",                    TREAT},
-#line 218 "TokenLookup.gperf"
-      {"xquery",                   XQUERY},
-#line 181 "TokenLookup.gperf"
-      {"ne",                       NE},
-      {"",ERROR},
-#line 198 "TokenLookup.gperf"
-      {"satisfies",                SATISFIES},
-      {"",ERROR}, {"",ERROR},
-#line 163 "TokenLookup.gperf"
-      {"gt",                       GT},
-#line 151 "TokenLookup.gperf"
-      {"encoding",                 ENCODING},
-#line 124 "TokenLookup.gperf"
-      {"ascending",                ASCENDING},
-      {"",ERROR},
-#line 125 "TokenLookup.gperf"
-      {"assign",                   ASSIGN},
-#line 139 "TokenLookup.gperf"
-      {"declare",                  DECLARE},
-#line 162 "TokenLookup.gperf"
-      {"greatest",                 GREATEST},
-#line 208 "TokenLookup.gperf"
-      {"then",                     THEN},
-      {"",ERROR},
-#line 121 "TokenLookup.gperf"
-      {"ancestor-or-self",         ANCESTOR_OR_SELF},
-#line 175 "TokenLookup.gperf"
-      {"le",                       LE},
-#line 146 "TokenLookup.gperf"
-      {"document-node",            DOCUMENT_NODE},
-#line 207 "TokenLookup.gperf"
-      {"text",                     TEXT},
-      {"",ERROR},
-#line 201 "TokenLookup.gperf"
-      {"schema",                   SCHEMA},
-      {"",ERROR},
-#line 145 "TokenLookup.gperf"
-      {"document",                 DOCUMENT},
-      {"",ERROR},
-#line 141 "TokenLookup.gperf"
-      {"descendant",               DESCENDANT},
-      {"",ERROR},
-#line 177 "TokenLookup.gperf"
-      {"lt",                       LT},
-#line 122 "TokenLookup.gperf"
-      {"and",                      AND},
-#line 182 "TokenLookup.gperf"
-      {"node",                     NODE},
-#line 174 "TokenLookup.gperf"
-      {"least",                    LEAST},
-#line 199 "TokenLookup.gperf"
-      {"schema-attribute",         SCHEMA_ATTRIBUTE},
-      {"",ERROR},
-#line 155 "TokenLookup.gperf"
-      {"external",                 EXTERNAL},
-      {"",ERROR},
-#line 143 "TokenLookup.gperf"
-      {"descending",               DESCENDING},
-#line 184 "TokenLookup.gperf"
-      {"no-preserve",              NO_PRESERVE},
-#line 140 "TokenLookup.gperf"
-      {"default",                  DEFAULT},
-#line 176 "TokenLookup.gperf"
-      {"let",                      LET},
-#line 200 "TokenLookup.gperf"
-      {"schema-element",           SCHEMA_ELEMENT},
-      {"",ERROR}, {"",ERROR},
-#line 137 "TokenLookup.gperf"
-      {"construction",             CONSTRUCTION},
-#line 142 "TokenLookup.gperf"
-      {"descendant-or-self",       DESCENDANT_OR_SELF},
-#line 202 "TokenLookup.gperf"
-      {"self",                     SELF},
-#line 183 "TokenLookup.gperf"
-      {"no-inherit",               NO_INHERIT},
-      {"",ERROR},
-#line 158 "TokenLookup.gperf"
-      {"follows",                  FOLLOWS},
-#line 120 "TokenLookup.gperf"
-      {"ancestor",                 ANCESTOR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR},
-#line 209 "TokenLookup.gperf"
-      {"to",                       TO},
-#line 160 "TokenLookup.gperf"
-      {"function",                 FUNCTION},
-#line 135 "TokenLookup.gperf"
-      {"collation",                COLLATION},
-      {"",ERROR},
-#line 205 "TokenLookup.gperf"
-      {"strict",                   STRICT},
-      {"",ERROR},
-#line 173 "TokenLookup.gperf"
-      {"lax",                      LAX},
-      {"",ERROR},
-#line 149 "TokenLookup.gperf"
-      {"empty",                    EMPTY},
-      {"",ERROR},
-#line 185 "TokenLookup.gperf"
-      {"of",                       OF},
-#line 195 "TokenLookup.gperf"
-      {"preserve",                 PRESERVE},
-#line 156 "TokenLookup.gperf"
-      {"following",                FOLLOWING},
-      {"",ERROR}, {"",ERROR},
-#line 171 "TokenLookup.gperf"
-      {"is",                       IS},
-#line 192 "TokenLookup.gperf"
-      {"precedes",                 PRECEDES},
-#line 150 "TokenLookup.gperf"
-      {"empty-sequence",           EMPTY_SEQUENCE},
-      {"",ERROR}, {"",ERROR},
-#line 157 "TokenLookup.gperf"
-      {"following-sibling",        FOLLOWING_SIBLING},
-#line 169 "TokenLookup.gperf"
-      {"instance",                 INSTANCE},
-#line 213 "TokenLookup.gperf"
-      {"unordered",                UNORDERED},
-#line 128 "TokenLookup.gperf"
-      {"base-uri",                 BASEURI},
-#line 197 "TokenLookup.gperf"
-      {"return",                   RETURN},
-      {"",ERROR},
-#line 214 "TokenLookup.gperf"
-      {"validate",                 VALIDATE},
-      {"",ERROR},
-#line 138 "TokenLookup.gperf"
-      {"copy-namespaces",          COPY_NAMESPACES},
-#line 186 "TokenLookup.gperf"
-      {"option",                   OPTION},
-#line 165 "TokenLookup.gperf"
-      {"if",                       IF},
-      {"",ERROR},
-#line 193 "TokenLookup.gperf"
-      {"preceding",                PRECEDING},
-      {"",ERROR}, {"",ERROR},
-#line 168 "TokenLookup.gperf"
-      {"in",                       IN},
-      {"",ERROR},
-#line 170 "TokenLookup.gperf"
-      {"intersect",                INTERSECT},
-#line 212 "TokenLookup.gperf"
-      {"union",                    UNION},
-      {"",ERROR},
-#line 194 "TokenLookup.gperf"
-      {"preceding-sibling",        PRECEDING_SIBLING},
-#line 188 "TokenLookup.gperf"
-      {"ordering",                 ORDERING},
-#line 203 "TokenLookup.gperf"
-      {"some",                     SOME},
-#line 134 "TokenLookup.gperf"
-      {"child",                    CHILD},
-      {"",ERROR},
-#line 187 "TokenLookup.gperf"
-      {"ordered",                  ORDERED},
-#line 215 "TokenLookup.gperf"
-      {"variable",                 VARIABLE},
-      {"",ERROR}, {"",ERROR}, {"",ERROR},
-#line 190 "TokenLookup.gperf"
-      {"or",                       OR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-#line 136 "TokenLookup.gperf"
-      {"comment",                  COMMENT},
-      {"",ERROR}, {"",ERROR},
-#line 211 "TokenLookup.gperf"
-      {"typeswitch",               TYPESWITCH},
-      {"",ERROR},
-#line 167 "TokenLookup.gperf"
-      {"inherit",                  INHERIT},
+      {"",T_ERROR}, {"",T_ERROR},
 #line 144 "TokenLookup.gperf"
-      {"div",                      DIV},
-      {"",ERROR}, {"",ERROR},
-#line 179 "TokenLookup.gperf"
-      {"module",                   MODULE},
-      {"",ERROR},
-#line 159 "TokenLookup.gperf"
-      {"for",                      FOR},
-#line 180 "TokenLookup.gperf"
-      {"namespace",                NAMESPACE},
-      {"",ERROR}, {"",ERROR},
-#line 216 "TokenLookup.gperf"
-      {"version",                  VERSION},
-      {"",ERROR}, {"",ERROR},
-#line 206 "TokenLookup.gperf"
-      {"strip",                    STRIP},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-#line 189 "TokenLookup.gperf"
-      {"order",                    ORDER},
-#line 191 "TokenLookup.gperf"
-      {"parent",                   PARENT},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR},
-#line 178 "TokenLookup.gperf"
-      {"mod",                      MOD},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR},
-#line 166 "TokenLookup.gperf"
-      {"import",                   IMPORT},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR},
+      {"eq",                       T_EQ},
+      {"",T_ERROR},
+#line 122 "TokenLookup.gperf"
+      {"by",                       T_BY},
+#line 145 "TokenLookup.gperf"
+      {"every",                    T_EVERY},
+      {"",T_ERROR},
+#line 115 "TokenLookup.gperf"
+      {"as",                       T_AS},
+      {"",T_ERROR},
+#line 140 "TokenLookup.gperf"
+      {"else",                     T_ELSE},
+#line 209 "TokenLookup.gperf"
+      {"where",                    T_WHERE},
 #line 196 "TokenLookup.gperf"
-      {"processing-instruction",   PROCESSING_INSTRUCTION},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR},
+      {"stable",                   T_STABLE},
+#line 118 "TokenLookup.gperf"
+      {"at",                       T_AT},
+      {"",T_ERROR},
+#line 123 "TokenLookup.gperf"
+      {"case",                     T_CASE},
+      {"",T_ERROR},
+#line 121 "TokenLookup.gperf"
+      {"boundary-space",           T_BOUNDARY_SPACE},
+#line 139 "TokenLookup.gperf"
+      {"element",                  T_ELEMENT},
+#line 124 "TokenLookup.gperf"
+      {"castable",                 T_CASTABLE},
+#line 119 "TokenLookup.gperf"
+      {"attribute",                T_ATTRIBUTE},
+      {"",T_ERROR},
+#line 146 "TokenLookup.gperf"
+      {"except",                   T_EXCEPT},
+#line 153 "TokenLookup.gperf"
+      {"ge",                       T_GE},
+      {"",T_ERROR},
+#line 125 "TokenLookup.gperf"
+      {"cast",                     T_CAST},
+#line 202 "TokenLookup.gperf"
+      {"treat",                    T_TREAT},
+#line 210 "TokenLookup.gperf"
+      {"xquery",                   T_XQUERY},
+#line 173 "TokenLookup.gperf"
+      {"ne",                       T_NE},
+      {"",T_ERROR},
+#line 190 "TokenLookup.gperf"
+      {"satisfies",                T_SATISFIES},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 155 "TokenLookup.gperf"
+      {"gt",                       T_GT},
+#line 143 "TokenLookup.gperf"
+      {"encoding",                 T_ENCODING},
+#line 116 "TokenLookup.gperf"
+      {"ascending",                T_ASCENDING},
+      {"",T_ERROR},
+#line 117 "TokenLookup.gperf"
+      {"assign",                   T_ASSIGN},
+#line 131 "TokenLookup.gperf"
+      {"declare",                  T_DECLARE},
+#line 154 "TokenLookup.gperf"
+      {"greatest",                 T_GREATEST},
+#line 200 "TokenLookup.gperf"
+      {"then",                     T_THEN},
+      {"",T_ERROR},
+#line 113 "TokenLookup.gperf"
+      {"ancestor-or-self",         T_ANCESTOR_OR_SELF},
+#line 167 "TokenLookup.gperf"
+      {"le",                       T_LE},
+#line 138 "TokenLookup.gperf"
+      {"document-node",            T_DOCUMENT_NODE},
+#line 199 "TokenLookup.gperf"
+      {"text",                     T_TEXT},
+      {"",T_ERROR},
+#line 193 "TokenLookup.gperf"
+      {"schema",                   T_SCHEMA},
+      {"",T_ERROR},
+#line 137 "TokenLookup.gperf"
+      {"document",                 T_DOCUMENT},
+      {"",T_ERROR},
+#line 133 "TokenLookup.gperf"
+      {"descendant",               T_DESCENDANT},
+      {"",T_ERROR},
+#line 169 "TokenLookup.gperf"
+      {"lt",                       T_LT},
+#line 114 "TokenLookup.gperf"
+      {"and",                      T_AND},
+#line 174 "TokenLookup.gperf"
+      {"node",                     T_NODE},
+#line 166 "TokenLookup.gperf"
+      {"least",                    T_LEAST},
+#line 191 "TokenLookup.gperf"
+      {"schema-attribute",         T_SCHEMA_ATTRIBUTE},
+      {"",T_ERROR},
+#line 147 "TokenLookup.gperf"
+      {"external",                 T_EXTERNAL},
+      {"",T_ERROR},
+#line 135 "TokenLookup.gperf"
+      {"descending",               T_DESCENDING},
+#line 176 "TokenLookup.gperf"
+      {"no-preserve",              T_NO_PRESERVE},
+#line 132 "TokenLookup.gperf"
+      {"default",                  T_DEFAULT},
+#line 168 "TokenLookup.gperf"
+      {"let",                      T_LET},
+#line 192 "TokenLookup.gperf"
+      {"schema-element",           T_SCHEMA_ELEMENT},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 129 "TokenLookup.gperf"
+      {"construction",             T_CONSTRUCTION},
+#line 134 "TokenLookup.gperf"
+      {"descendant-or-self",       T_DESCENDANT_OR_SELF},
+#line 194 "TokenLookup.gperf"
+      {"self",                     T_SELF},
+#line 175 "TokenLookup.gperf"
+      {"no-inherit",               T_NO_INHERIT},
+      {"",T_ERROR},
+#line 150 "TokenLookup.gperf"
+      {"follows",                  T_FOLLOWS},
+#line 112 "TokenLookup.gperf"
+      {"ancestor",                 T_ANCESTOR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+#line 201 "TokenLookup.gperf"
+      {"to",                       T_TO},
+#line 152 "TokenLookup.gperf"
+      {"function",                 T_FUNCTION},
+#line 127 "TokenLookup.gperf"
+      {"collation",                T_COLLATION},
+      {"",T_ERROR},
+#line 197 "TokenLookup.gperf"
+      {"strict",                   T_STRICT},
+      {"",T_ERROR},
+#line 165 "TokenLookup.gperf"
+      {"lax",                      T_LAX},
+      {"",T_ERROR},
+#line 141 "TokenLookup.gperf"
+      {"empty",                    T_EMPTY},
+      {"",T_ERROR},
+#line 177 "TokenLookup.gperf"
+      {"of",                       T_OF},
+#line 187 "TokenLookup.gperf"
+      {"preserve",                 T_PRESERVE},
+#line 148 "TokenLookup.gperf"
+      {"following",                T_FOLLOWING},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 163 "TokenLookup.gperf"
+      {"is",                       T_IS},
+#line 184 "TokenLookup.gperf"
+      {"precedes",                 T_PRECEDES},
+#line 142 "TokenLookup.gperf"
+      {"empty-sequence",           T_EMPTY_SEQUENCE},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 149 "TokenLookup.gperf"
+      {"following-sibling",        T_FOLLOWING_SIBLING},
+#line 161 "TokenLookup.gperf"
+      {"instance",                 T_INSTANCE},
+#line 205 "TokenLookup.gperf"
+      {"unordered",                T_UNORDERED},
+#line 120 "TokenLookup.gperf"
+      {"base-uri",                 T_BASEURI},
+#line 189 "TokenLookup.gperf"
+      {"return",                   T_RETURN},
+      {"",T_ERROR},
+#line 206 "TokenLookup.gperf"
+      {"validate",                 T_VALIDATE},
+      {"",T_ERROR},
+#line 130 "TokenLookup.gperf"
+      {"copy-namespaces",          T_COPY_NAMESPACES},
+#line 178 "TokenLookup.gperf"
+      {"option",                   T_OPTION},
+#line 157 "TokenLookup.gperf"
+      {"if",                       T_IF},
+      {"",T_ERROR},
+#line 185 "TokenLookup.gperf"
+      {"preceding",                T_PRECEDING},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 160 "TokenLookup.gperf"
+      {"in",                       T_IN},
+      {"",T_ERROR},
+#line 162 "TokenLookup.gperf"
+      {"intersect",                T_INTERSECT},
+#line 204 "TokenLookup.gperf"
+      {"union",                    T_UNION},
+      {"",T_ERROR},
+#line 186 "TokenLookup.gperf"
+      {"preceding-sibling",        T_PRECEDING_SIBLING},
+#line 180 "TokenLookup.gperf"
+      {"ordering",                 T_ORDERING},
+#line 195 "TokenLookup.gperf"
+      {"some",                     T_SOME},
+#line 126 "TokenLookup.gperf"
+      {"child",                    T_CHILD},
+      {"",T_ERROR},
+#line 179 "TokenLookup.gperf"
+      {"ordered",                  T_ORDERED},
+#line 207 "TokenLookup.gperf"
+      {"variable",                 T_VARIABLE},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+#line 182 "TokenLookup.gperf"
+      {"or",                       T_OR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+#line 128 "TokenLookup.gperf"
+      {"comment",                  T_COMMENT},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 203 "TokenLookup.gperf"
+      {"typeswitch",               T_TYPESWITCH},
+      {"",T_ERROR},
+#line 159 "TokenLookup.gperf"
+      {"inherit",                  T_INHERIT},
+#line 136 "TokenLookup.gperf"
+      {"div",                      T_DIV},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 171 "TokenLookup.gperf"
+      {"module",                   T_MODULE},
+      {"",T_ERROR},
+#line 151 "TokenLookup.gperf"
+      {"for",                      T_FOR},
 #line 172 "TokenLookup.gperf"
-      {"item",                     ITEM},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR}, {"",ERROR}, {"",ERROR}, {"",ERROR},
-      {"",ERROR},
+      {"namespace",                T_NAMESPACE},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 208 "TokenLookup.gperf"
+      {"version",                  T_VERSION},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 198 "TokenLookup.gperf"
+      {"strip",                    T_STRIP},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+#line 181 "TokenLookup.gperf"
+      {"order",                    T_ORDER},
+#line 183 "TokenLookup.gperf"
+      {"parent",                   T_PARENT},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 170 "TokenLookup.gperf"
+      {"mod",                      T_MOD},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR},
+#line 158 "TokenLookup.gperf"
+      {"import",                   T_IMPORT},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR},
+#line 188 "TokenLookup.gperf"
+      {"processing-instruction",   T_PROCESSING_INSTRUCTION},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR},
 #line 164 "TokenLookup.gperf"
-      {"idiv",                     IDIV}
+      {"item",                     T_ITEM},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR}, {"",T_ERROR},
+      {"",T_ERROR},
+#line 156 "TokenLookup.gperf"
+      {"idiv",                     T_IDIV}
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      int key = hash (str, len);
+      register int key = hash (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= 0)
         {
-          const char *s = wordlist[key].name;
+          register const char *s = wordlist[key].name;
 
           if (*str == *s && !strcmp (str + 1, s + 1))
             return &wordlist[key];
@@ -428,7 +428,7 @@ TokenLookup::value (const char *str, unsigned int len)
     }
   return 0;
 }
-#line 219 "TokenLookup.gperf"
+#line 211 "TokenLookup.gperf"
 
 
 } /* Close the QPatternist namespace. */
