@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -104,10 +96,9 @@ tst_XmlPatterns::tst_XmlPatterns() : m_generatedTests(0)
 
 void tst_XmlPatterns::initTestCase()
 {
-    QVERIFY(QtNetworkSettings::verifyTestNetworkSettings());
-
     QVERIFY(m_normalizeTestName.isValid());
 
+#ifndef QT_NO_PROCESS
     QProcess process;
     process.start(m_command);
 
@@ -121,11 +112,17 @@ void tst_XmlPatterns::initTestCase()
             ).arg(m_command))
         );
     }
-
+#else
+    QSKIP("Skipping test due to not having process support");
+#endif // QT_NO_PROCESS
 }
 
 void tst_XmlPatterns::xquerySupport()
 {
+    if (QTest::currentDataTag() == QByteArray("Load query via FTP")
+            || QTest::currentDataTag() == QByteArray("Load query via HTTP"))
+        QVERIFY(QtNetworkSettings::verifyTestNetworkSettings());
+
     if(m_dontRun)
         QSKIP("The command line utility is not in the path.");
 
@@ -133,6 +130,7 @@ void tst_XmlPatterns::xquerySupport()
     QSKIP("WinCE: This test uses unsupported WinCE functionality");
 #endif
 
+#ifndef QT_NO_PROCESS
     QFETCH(int,         expectedExitCode);
     QFETCH(QByteArray,  expectedQueryOutput);
     QFETCH(QStringList, arguments);
@@ -217,6 +215,10 @@ void tst_XmlPatterns::xquerySupport()
 
         removeNonWritable(outFile);
     }
+
+#else
+    QSKIP("Skipping test due to not having process support");
+#endif // QT_NO_PROCESS
 }
 
 void tst_XmlPatterns::xquerySupport_data() const
@@ -753,6 +755,13 @@ void tst_XmlPatterns::xquerySupport_data() const
         << QString()
         << QString();
 
+    QTest::newRow("QTBUG-35897: literal sequence")
+            << 0
+            << QByteArray("someString a b\n")
+            << QStringList((path + QStringLiteral("literalsequence.xq")))
+            << QString()
+            << QString();
+
     // TODO https?
     // TODO pass external variables that allows space around the equal sign.
     // TODO run fn:trace()
@@ -802,6 +811,7 @@ void tst_XmlPatterns::removeNonWritable(QFile &outFile)
 void tst_XmlPatterns::stdoutFailure() const
 {
     return; // TODO It's really hard to write testing code for this.
+#ifndef QT_NO_PROCESS
 
     const QString outName(QLatin1String("stdoutFailure.out"));
     createNonWritable(outName);
@@ -823,6 +833,9 @@ void tst_XmlPatterns::stdoutFailure() const
     QCOMPARE(process.exitCode(), 1);
 
     removeNonWritable(outFile);
+#else
+    QSKIP("Skipping test due to not having process support");
+#endif // QT_NO_PROCESS
 }
 
 void tst_XmlPatterns::cleanupTestCase() const
