@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -403,7 +395,7 @@ void QApplicationArgumentParserPrivate::displayHelp() const
         /* "  -name ". Indent a bit first, inspired by Qt's moc. */
         const QString &name = at.name();
         QString prolog(QLatin1String("  "));
-       
+
         /* We have a special case for the single dash. */
         if(name == QChar::fromLatin1('-'))
             prolog.append(name);
@@ -427,7 +419,7 @@ void QApplicationArgumentParserPrivate::displayHelp() const
             else
                 prolog.append(QLatin1Char('<') + typeName + QLatin1Char('>'));
             // TODO Don't we want to display the default value?
-            
+
             prolog.append(QLatin1Char(' '));
         }
 
@@ -464,7 +456,7 @@ QString QApplicationArgumentParserPrivate::lineWrap(const QString &input,
         return input;
 
     int from = wrapFinder.toPreviousBoundary();
-    output.append(input.left(from));
+    output.append(input.leftRef(from));
 
     while(true)
     {
@@ -476,7 +468,7 @@ QString QApplicationArgumentParserPrivate::lineWrap(const QString &input,
 
             output.append(QLatin1Char('\n'));
             output.append(indent);
-            output.append(input.mid(from, currentWidthPos - from).trimmed());
+            output.append(input.midRef(from, currentWidthPos - from).trimmed().toString());
             from += (currentWidthPos - from);
         }
         else
@@ -484,7 +476,7 @@ QString QApplicationArgumentParserPrivate::lineWrap(const QString &input,
             /* Append the remains.  */
             output.append(QLatin1Char('\n'));
             output.append(indent);
-            output.append(input.mid(from).trimmed());
+            output.append(input.midRef(from).trimmed().toString());
             break;
         }
     }
@@ -503,7 +495,7 @@ QList<QApplicationArgument> QApplicationArgumentParserPrivate::builtinArguments(
                                        QLatin1String("Displays this help.")));
     result.append(QApplicationArgument(QLatin1String("version"),
                                        QLatin1String("Displays version information.")));
-    
+
     result.append(QApplicationArgument(QLatin1String("-"),
                                        QLatin1String("When appearing, any following options are not interpreted as switches.")));
     return result;
@@ -644,7 +636,7 @@ bool QApplicationArgumentParserPrivate::parseNamelessArguments(const QString &in
 }
 
 /*!
- Parses input() together with declaredArguments() and returns \c false if the caller 
+ Parses input() together with declaredArguments() and returns \c false if the caller
  should exit immediately, which is the case of which an error was encountered or
  help or the version was requested.
 
